summaryrefslogtreecommitdiffstats
path: root/src/extension/internal/ps.cpp
diff options
context:
space:
mode:
authorbulia byak <buliabyak@gmail.com>2006-12-11 02:40:10 +0000
committerbuliabyak <buliabyak@users.sourceforge.net>2006-12-11 02:40:10 +0000
commit72e908d5722521ece0890ce6df6f425dd6e0ffef (patch)
tree51ff0a3b763bea23159352d949516a4f53221de5 /src/extension/internal/ps.cpp
parentfix compile (diff)
downloadinkscape-72e908d5722521ece0890ce6df6f425dd6e0ffef.tar.gz
inkscape-72e908d5722521ece0890ce6df6f425dd6e0ffef.zip
last fixes from patch 1219308
(bzr r2087)
Diffstat (limited to 'src/extension/internal/ps.cpp')
-rw-r--r--src/extension/internal/ps.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/extension/internal/ps.cpp b/src/extension/internal/ps.cpp
index 6392c33d8..a5208cfee 100644
--- a/src/extension/internal/ps.cpp
+++ b/src/extension/internal/ps.cpp
@@ -64,7 +64,7 @@
#include <ft2build.h>
#include FT_FREETYPE_H
-#include <freetype/ftxf86.h>
+#include FT_XFREE86_H
#include <pango/pangoft2.h>
#include <string>
#include <iostream>
@@ -81,8 +81,8 @@ PrintPS::PrintPS() :
_bitmap(false)
{
//map font types
- _fontTypesMap["type1"] = FONT_TYPE1;
- _fontTypesMap["truetype"] = FONT_TRUETYPE;
+ _fontTypesMap["Type 1"] = FONT_TYPE1;
+ _fontTypesMap["TrueType"] = FONT_TRUETYPE;
//TODO: support other font types (cf. embed_font())
}
@@ -1153,10 +1153,10 @@ bool PrintPS::embed_font(SVGOStringStream &os, font_instance* font)
const FT_String* font_type = FT_Get_X11_Font_Format(font_face);
/**
- * Possible values of "font_type" variable, not supported (font types):
- * truetype, cff, t1cid, sfnt, bdf, pcf, pfr, winfonts (FNT/FON).
+ * Possible values of "font_type": Type 1, TrueType, etc.
+ * Embedding available only for Type 1 fonts so far.
*/
//TODO: provide support for the font types above
switch(_fontTypesMap[font_type])
{
case FONT_TYPE1:
@@ -1153,10 +1153,10 @@ bool PrintPS::embed_font(SVGOStringStream &os, font_instance* font)
*/
- //TODO: provide support for the font types above
+ //TODO: provide support for other font types (TrueType is a priority)
switch(_fontTypesMap[font_type])
{